@@ -10,13 +10,12 @@
 #include <array> // std::array
 #include <limits> // std::numeric_limits
 #include <memory> // std::allocator
-#include <ostream>
 #include <string>
 #include <unordered_map> // std::unordered_map
 #include <utility> // std::move
 #include <vector>
 
-#include <jsoncons/detail/write_number.hpp>
+#include <jsoncons/utility/write_number.hpp>
 #include <jsoncons/json_encoder.hpp>
 #include <jsoncons/json_exception.hpp>
 #include <jsoncons/json_visitor.hpp>
@@ -25,7 +24,8 @@
 #include <jsoncons_ext/csv/csv_options.hpp>
 #include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
 
-namespace jsoncons { namespace csv {
+namespace jsoncons { 
+namespace csv {
 
 template <typename CharT,typename Sink=jsoncons::stream_sink<CharT>,typename Allocator=std::allocator<char>>
 class basic_csv_encoder final : public basic_json_visitor<CharT>
@@ -127,7 +127,7 @@ private:
     allocator_type alloc_;
 
     std::vector<stack_item, stack_item_allocator_type> stack_;
-    jsoncons::detail::write_double fp_;
+    jsoncons::utility::write_double fp_;
 
     std::vector<string_type,string_allocator_type> column_names_;
     std::vector<string_type,string_allocator_type> column_paths_;
@@ -516,7 +516,7 @@ private:
                 {
                     string_type str{alloc_};
                     str.push_back('/');
-                    jsoncons::detail::from_integer(index, str);
+                    jsoncons::utility::from_integer(index, str);
                     column_paths_.emplace_back(str);
                     column_path_value_map_.emplace(str, string_type{alloc_});
                     column_path_name_map_.emplace(std::move(str), item);
@@ -802,7 +802,7 @@ private:
     {
         stack_.back().column_path_ = parent(stack_).column_path_;
         stack_.back().column_path_.push_back('/');
-        jsoncons::detail::from_integer(stack_.back().count_, stack_.back().column_path_);
+        jsoncons::utility::from_integer(stack_.back().count_, stack_.back().column_path_);
         if (stack_[0].count_ == 0)
         {
             if (!has_column_mapping_)
@@ -989,19 +989,19 @@ private:
         {
             case byte_string_chars_format::base16:
             {
-                encode_base16(b.begin(),b.end(),s);
+                bytes_to_base16(b.begin(),b.end(),s);
                 visit_string(s, semantic_tag::none, context, ec);
                 break;
             }
             case byte_string_chars_format::base64:
             {
-                encode_base64(b.begin(),b.end(),s);
+                bytes_to_base64(b.begin(),b.end(),s);
                 visit_string(s, semantic_tag::none, context, ec);
                 break;
             }
             case byte_string_chars_format::base64url:
             {
-                encode_base64url(b.begin(),b.end(),s);
+                bytes_to_base64url(b.begin(),b.end(),s);
                 visit_string(s, semantic_tag::none, context, ec);
                 break;
             }
@@ -1385,12 +1385,12 @@ private:
 
     void write_int64_value(int64_t val, string_type& str)
     {
-        jsoncons::detail::from_integer(val,str);
+        jsoncons::utility::from_integer(val,str);
     }
 
     void write_uint64_value(uint64_t val, string_type& str)
     {
-        jsoncons::detail::from_integer(val,str);
+        jsoncons::utility::from_integer(val,str);
     }
 
     void write_bool_value(bool val, string_type& str) 
