@@ -1,4 +1,4 @@
-/// Copyright 2013-2024 Daniel Parker
+/// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,6 +7,8 @@
 #ifndef JSONCONS_EXT_JSONSCHEMA_JSONSCHEMA_ERROR_HPP
 #define JSONCONS_EXT_JSONSCHEMA_JSONSCHEMA_ERROR_HPP
 
+#include <string>
+#include <stdexcept>
 #include <system_error>
 
 #include <jsoncons/json_exception.hpp>
