@@ -171,7 +171,7 @@ TEST_CASE("bson encode array")
         std::vector<uint8_t> data;
         bson::encode_bson(p, data);
 
-        CHECK(data == expected);
+        CHECK(expected == data);
 
         auto p2 = bson::decode_bson<std::pair<int,int>>(data);
         CHECK(p2 == p);
@@ -180,11 +180,11 @@ TEST_CASE("bson encode array")
 
 #if defined(JSONCONS_HAS_STATEFUL_ALLOCATOR) && JSONCONS_HAS_STATEFUL_ALLOCATOR == 1
 
-#include <common/free_list_allocator.hpp>
+#include <common/mock_stateful_allocator.hpp>
 #include <scoped_allocator>
 
 template <typename T>
-using MyScopedAllocator = std::scoped_allocator_adaptor<free_list_allocator<T>>;
+using MyScopedAllocator = std::scoped_allocator_adaptor<mock_stateful_allocator<T>>;
 using cust_json = basic_json<char,sorted_policy,MyScopedAllocator<char>>;
 
 TEST_CASE("encode decode bson source with temp_allocator")
@@ -205,14 +205,14 @@ TEST_CASE("encode decode bson source with temp_allocator")
             0x00};
 
     MyScopedAllocator<char> temp_alloc(2);
-    auto alloc_set = temp_allocator_only(temp_alloc);    
+    auto aset = make_alloc_set(temp_alloc_arg, temp_alloc);    
 
     SECTION("from bytes")
     {
-        auto j = bson::decode_bson<ojson>(alloc_set, input);
+        auto j = bson::decode_bson<ojson>(aset, input);
 
         std::vector<uint8_t> buffer;
-        bson::encode_bson(alloc_set, j, buffer);
+        bson::encode_bson(aset, j, buffer);
         CHECK(buffer == input);
     }
 
@@ -221,10 +221,10 @@ TEST_CASE("encode decode bson source with temp_allocator")
         std::string s(reinterpret_cast<const char*>(input.data()), input.size());
         std::stringstream is(std::move(s));
 
-        auto j = bson::decode_bson<ojson>(alloc_set, is);
+        auto j = bson::decode_bson<ojson>(aset, is);
 
         std::vector<uint8_t> buffer;
-        bson::encode_bson(alloc_set, j, buffer);
+        bson::encode_bson(aset, j, buffer);
         CHECK(buffer == input);
     }
 
